==> mm3d_1.3.6.orig.tar.gz: mm3d-1.3.6/src/commands/invertcmd.cc <==
/*  Misfit Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#include "invertcmd.h"

#include "model.h"
#include "log.h"
#include "msg.h"
#include "modelstatus.h"
#include <qobject.h>
#include <qapplication.h>

InvertSelectionCommand::InvertSelectionCommand()
{
}

InvertSelectionCommand::~InvertSelectionCommand()
{
}

bool InvertSelectionCommand::activated( int arg, Model * model )
{
   if ( model )
   {
      model->invertSelection();
      model_status( model, StatusNormal, STATUSTIME_SHORT, qApp->translate( "Command", "Selection inverted" ).utf8() );
      return true;
   }
   else
   {
      return false;
   }
}

const char * InvertSelectionCommand::getName( int arg )
{
   return QT_TRANSLATE_NOOP( "Command", "Invert Selection" );
}

==> mm3d_1.3.7.orig.tar.gz: mm3d-1.3.7/src/commands/invertcmd.cc <==
/*  Misfit Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#include "invertcmd.h"

#include "model.h"
#include "log.h"
#include "msg.h"
#include "modelstatus.h"
#include <QtCore/QObject>
#include <QtGui/QApplication>

InvertSelectionCommand::InvertSelectionCommand()
{
}

InvertSelectionCommand::~InvertSelectionCommand()
{
}

bool InvertSelectionCommand::activated( int arg, Model * model )
{
   if ( model )
   {
      model->invertSelection();
      model_status( model, StatusNormal, STATUSTIME_SHORT, qApp->translate( "Command", "Selection inverted" ).toUtf8() );
      return true;
   }
   else
   {
      return false;
   }
}

const char * InvertSelectionCommand::getName( int arg )
{
   return QT_TRANSLATE_NOOP( "Command", "Invert Selection" );
}
